@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package XML::Saxtract;
-$XML::Saxtract::VERSION = '1.01';
+$XML::Saxtract::VERSION = '1.02';
 # ABSTRACT: Streaming parse XML data into a result hash based upon a specification hash
 # PODNAME: XML::Saxtract
 
@@ -45,7 +45,7 @@ sub saxtract_url {
 }
 
 package XML::Saxtract::ContentHandler;
-$XML::Saxtract::ContentHandler::VERSION = '1.01';
+$XML::Saxtract::ContentHandler::VERSION = '1.02';
 use parent qw(Class::Accessor);
 __PACKAGE__->follow_best_practice;
 __PACKAGE__->mk_ro_accessors(qw(result));
@@ -168,6 +168,17 @@ sub _init {
     return $self;
 }
 
+sub _spec_prefix {
+    my ( $self, $uri ) = @_;
+
+    for ( my $i = scalar( @{ $self->{element_stack} } ) - 1; $i >= 0; $i-- ) {
+        my $spec_prefix = $self->{element_stack}[$i]->{spec}{$uri};
+        return $spec_prefix if ( defined($spec_prefix) );
+    }
+
+    return;
+}
+
 sub start_element {
     my ( $self, $element ) = @_;
 
@@ -183,7 +194,7 @@ sub start_element {
 
     my $qname;
     if ($uri) {
-        my $spec_prefix = $spec->{$uri};
+        my $spec_prefix = $self->_spec_prefix($uri);
         if ( !defined($spec_prefix) ) {
 
             # uri is not in spec, so nothing could possibly match
@@ -234,7 +245,7 @@ XML::Saxtract - Streaming parse XML data into a result hash based upon a specifi
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
